==> Gbook-1.0.1.tar.gz: Gbook/function.admin_gbookstab.php <==
<?php
#-------------------------------------------------------------------------
# Module: Gbook
# Author: Jos (josvd@live.nl)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2008 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/gbook/
#-------------------------------------------------------------------------


$smarty->assign('gbook', $this->Lang('gbooks'));
$smarty->assign('tag', lang('tags'));
$smarty->assign('entries', $this->Lang('entries'));
$smarty->assign('default', lang('default'));
$smarty->assign('active', lang('active'));

$smarty->assign('defaultgbook', $this->GetPreference('defaultgbook'));
$smarty->assign('defaulttrue', $themeObject->DisplayImage('icons/system/true.gif',lang ('default')));
$smarty->assign('defaultfalselink', $this->CreateLink($id, 'editgbook', $returnid,
				    $themeObject->DisplayImage('icons/system/false.gif',lang ('settrue'),'','','systemicon'),
				    array('gbookid' => 'QQ', 'mode' => 'switchdefault')));

$smarty->assign('activetruelink', $this->CreateLink($id, 'editgbook', $returnid,
				    $themeObject->DisplayImage('icons/system/true.gif',lang ('setfalse'),'','','systemicon'),
				    array('gbookid' => 'QQ', 'mode' => 'switchactive')));
$smarty->assign('activefalselink', $this->CreateLink($id, 'editgbook', $returnid,
				    $themeObject->DisplayImage('icons/system/false.gif',lang ('settrue'),'','','systemicon'),
				    array('gbookid' => 'QQ', 'mode' => 'switchactive')));

$smarty->assign('editicon', $themeObject->DisplayImage ('icons/system/edit.gif', lang ('edit'), '', '', 'systemicon'));
$smarty->assign('editurl', $this->CreateLink($id, 'editgbook', $returnid,
				    lang ('edit'),
				    array ('gbookid' => 'QQ', 'mode'=>'edit'), '', true));
$smarty->assign('deletelink', $this->CreateLink($id, 'editgbook', $returnid,
					  $themeObject->DisplayImage('icons/system/delete.gif', lang ('delete'), '', '', 'systemicon'),
					  array ('gbookid' => 'QQ', 'mode'=>'delete'), $this->Lang ('areyousure')));


$smarty->assign('addlink', $this->CreateLink($id, 'editgbook', 0, $themeObject->DisplayImage('icons/system/newobject.gif', $this->Lang('addgbook'),'','','systemicon'), array(), '', false, false, '') .' '. $this->CreateLink($id, 'editgbook', $returnid, $this->Lang("addgbook"), array("mode"=>"add"), '', false, false, 'class="pageoptions"'));


// Display the populated template
echo $this->ProcessTemplate ('admingbooks.tpl');

?>

==> Gbook-2.2.5.tar.gz: Gbook/function.admin_gbookstab.php <==
<?php
#-------------------------------------------------------------------------
# Module: Gbook
# Author: Jos (josvd@live.nl)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2008 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/gbook/
#-------------------------------------------------------------------------


$smarty->assign('gbook', $this->Lang('gbooks'));
$smarty->assign('tag', lang('tags'));
$smarty->assign('entries', $this->Lang('entries'));
$smarty->assign('default', lang('default'));
$smarty->assign('active', lang('active'));

$smarty->assign('defaultgbook', $this->GetPreference('defaultgbook'));
$smarty->assign('defaulttrue', $admintheme->DisplayImage('icons/system/true.gif',lang ('default')));
$smarty->assign('defaultfalselink', $this->CreateLink($id, 'editgbook', $returnid,
				    $admintheme->DisplayImage('icons/system/false.gif',lang ('settrue'),'','','systemicon'),
				    array('gbookid' => 'QQ', 'mode' => 'switchdefault')));

$smarty->assign('activetruelink', $this->CreateLink($id, 'editgbook', $returnid,
				    $admintheme->DisplayImage('icons/system/true.gif',lang ('setfalse'),'','','systemicon'),
				    array('gbookid' => 'QQ', 'mode' => 'switchactive')));
$smarty->assign('activefalselink', $this->CreateLink($id, 'editgbook', $returnid,
				    $admintheme->DisplayImage('icons/system/false.gif',lang ('settrue'),'','','systemicon'),
				    array('gbookid' => 'QQ', 'mode' => 'switchactive')));

$smarty->assign('editicon', $admintheme->DisplayImage ('icons/system/edit.gif', lang ('edit'), '', '', 'systemicon'));
$smarty->assign('editurl', $this->CreateLink($id, 'editgbook', $returnid,
				    lang ('edit'),
				    array ('gbookid' => 'QQ', 'mode'=>'edit'), '', true));
$smarty->assign('deletelink', $this->CreateLink($id, 'editgbook', $returnid,
					  $admintheme->DisplayImage('icons/system/delete.gif', lang ('delete'), '', '', 'systemicon'),
					  array ('gbookid' => 'QQ', 'mode'=>'delete'), $this->Lang ('areyousure')));


$smarty->assign('addlink', $this->CreateLink($id, 'editgbook', 0, $admintheme->DisplayImage('icons/system/newobject.gif', $this->Lang('addgbook'),'','','systemicon'), array(), '', false, false, '') .' '. $this->CreateLink($id, 'editgbook', $returnid, $this->Lang("addgbook"), array("mode"=>"add"), '', false, false, 'class="pageoptions"'));


// Display the populated template
echo $this->ProcessTemplate ('admingbooks.tpl');

?>
